@@ -1,9 +1,9 @@
-import add_path
-from lglobals import *
-from i_scrape_old import old_entry
 from collections import ChainMap
-from j_lasla import convert2txt
-from a_colat4 import bottom_most_a4
+from latin.bglobals import *
+if not public:
+    from latin.i_scrape_old import old_entry
+from latin.j_lasla import convert2txt
+from latin.c_colat4 import bottom_most_a4
 
 lafold = f'{lfold}lasla/'
 
