@@ -1,5 +1,4 @@
-import add_path
-from lglobals import *
+from latin.bglobals import *
 
 
 def help():
